==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/layouts/activity-panel/es_cr.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', [
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Panel de actividad',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Dar click para abrir el panel de actividades.',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Redactar una nueva entrada de registro',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Cerrar',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Cargar tooas las entradas previas',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Cargar más entradas',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Al presionar el botón "Guardar", enviará entradas para todos las bitácoras editadas a la vez.',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Guardar varias bitácoras',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Está tranquilo aquí, aún no hay actividad.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Haga click para abrir la pestaña de notificaciones y obtener más información',
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Expandir',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Reducir',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Actividad',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Borrador de entrada',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Cerrar todas las entradas',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Abrir todas las entradas',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Ediciones',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Mostrar/ocultar ediciones de campos en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Elija qué bitácora mostrar en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Bitácoras',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Mostrar/ocultar entradas en bitácora en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Cambios de estado',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Mostrar/ocultar cambios de estado en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Número de personas interactuando en las entradas visibles',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Número de mensajes visibles en las bitácoras',
]);

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/layouts/activity-panel/es_cr.dictionary.itop.activity-panel.php <==
<?php
/**
 * Spanish Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 * @notas       Utilizar codificación UTF-8 para mostrar acentos y otros caracteres especiales 
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Expandir',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Reducir',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Cerrar',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Cargar más entradas',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Cargar tooas las entradas previas',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Actividad',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Borrador de entrada',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Bitácoras',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Mostrar/ocultar entradas en bitácora en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Elija qué bitácora mostrar en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Cambios de estado',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Mostrar/ocultar cambios de estado en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Ediciones',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Mostrar/ocultar ediciones de campos en esta pestaña',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Abrir todas las entradas',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Cerrar todas las entradas',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Número de personas interactuando en las entradas visibles',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Número de mensajes visibles en las bitácoras',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Redactar una nueva entrada de registro',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Guardar varias bitácoras',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Al presionar el botón "Guardar", enviará entradas para todos las bitácoras editadas a la vez.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Haga click para abrir la pestaña de notificaciones y obtener más información',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Está tranquilo aquí, aún no hay actividad.',
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Panel de actividad',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Dar click para abrir el panel de actividades.',
));
